# PyColors2

This is a set of color methods and a dictionary that help you wrap
text output in colors.  This tool was originally forked from the
Fabric fabric.colors library and upgraded with utilities from the
original pycolors tool in pypi.

Maintainer: Chris Gilmer

[![Build Status](https://travis-ci.org/chrisgilmerproj/pycolors2.png)](https://travis-ci.org/chrisgilmerproj/pycolors2)

[PyColors2 ReadTheDocs](http://pycolors2.readthedocs.org/en/latest/)
